##  Configuring Status Emails
As a cloud administrator or super administrator, you can manage subscriptions for yourself and other users. This includes users with or without S-user authorization who can receive status emails, but can’t configure status emails for themselves.
  1. In SAP for Me, navigate to Systems and Provisioning Get Notified.
![Get Notified page in SAP for me showing where admins can create subscriptions for notifications](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio4542767ab63549b1ac05f37884cae41b_HiRes.png)
  2. Click Add New Subscription to configure status emails. For detailed instructions, see [https://support.sap.com/content/dam/support/en_us/library/ssp/my-support/systems-installations/cac/csns-user-guide.pdf![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.sap.com%2Fcontent%2Fdam%2Fsupport%2Fen_us%2Flibrary%2Fssp%2Fmy-support%2Fsystems-installations%2Fcac%2Fcsns-user-guide.pdf "https://support.sap.com/content/dam/support/en_us/library/ssp/my-support/systems-installations/cac/csns-user-guide.pdf").
